<?php
namespace OCA\Dematpayslip\Settings;

use OCP\AppFramework\Http\TemplateResponse;
use OCP\Settings\ISettings;
use OCP\IL10N;

use OCA\Dematpayslip\Db\DematpayslipUserMapper;
use OCA\Dematpayslip\Db\DematpayslipUser;

class PersonalSettings implements ISettings {

    private $appName;

    /** @var IL10N */
    private $l;

    /** @var string User Id */
    private $userId;

    /** @var DematpayslipUserMapper*/
    private $_dematpayslipUserMapper;

    /** @var DematpayslipUser */
    private $_dematpayslipUser;

    /** @var array Message List */
    private $_msgList = array(
        'error'   => array(),
        'success' => array(),
        'warning' => array(),
    );

    /**
     * Assign params for template
     *
     * @return  array   Params for template
     */
    private function _assignParams() {
        return array(
            'dematpayslipUserList' => $this->_dematpayslipUserList,
            'msgList'              => $this->_msgList,
        );
    }

    /**
     * PersonalSettings constructor.
     *
     * @param   string                  $AppName                    App name
     * @param   IL10N                   $l                          Lang
     * @param   DematpayslipUserMapper  $dematpayslipUserMapper     Dematpayslip user mapper
     * @param   string                  $UserId                     User Id
     */
	public function __construct(
	    $AppName,
        IL10N $l,
        DematpayslipUserMapper $dematpayslipUserMapper,
        $UserId
    ) {
        $this->appName                 = $AppName;
        $this->l                       = $l;
        $this->_dematpayslipUserMapper = $dematpayslipUserMapper;
        $this->userId                  = $UserId;

        $dematpayslipUserList = $this->_dematpayslipUserMapper->findAllByUserId($this->userId);
        if (count($dematpayslipUserList) >= 1) {
            $this->_dematpayslipUserList = $dematpayslipUserList;
        } else {
            $this->_msgList['error'][] = $this->l->t('Cet utilisateur n\'a pas encore de bulletin de paie dématérialisé.');
        }
	}

	/**
	 * @return TemplateResponse
	 */
	public function getForm() {
        $action = filter_input(INPUT_GET, 'action', FILTER_SANITIZE_STRING);

        if ($action === 'dematpayslip_user') {
            $dematpayslipUserDisabledList = filter_input(INPUT_GET, 'dematpayslip_user_disabled', FILTER_DEFAULT, FILTER_REQUIRE_ARRAY);
            if (count($this->_dematpayslipUserList) >= 1) {
                $dateTimeNow = new \DateTime('now', \OC::$server->getDateTimeZone()->getTimeZone());

                foreach ($this->_dematpayslipUserList as $dematpayslipUser) {
                    if (isset($dematpayslipUserDisabledList[$dematpayslipUser->getSiret()])) {
                        // disable
                        $dematpayslipUserDisabled = 1;
                    } else {
                        // enable
                        $dematpayslipUserDisabled = 0;
                    }
                    $dematpayslipUser->setDisabled($dematpayslipUserDisabled);
                    $dematpayslipUser->setLastmodified($dateTimeNow->getTimestamp());
                    $this->_dematpayslipUserMapper->update($dematpayslipUser);
                }
            }
        }

        if (!empty($action)) {
            if (count($this->_msgList['error']) <= 0) {
                $this->_msgList['success'][] = $this->l->t('Opération réussie.');
            }
        }

		return new TemplateResponse($this->appName, 'settings/personal', $this->_assignParams(), '');
	}

	/**
	 * @return string the section ID, e.g. 'sharing'
	 */
	public function getSection() {
		return 'dematpayslip';
	}

	/**
	 * @return int whether the form should be rather on the top or bottom of
	 * the admin section. The forms are arranged in ascending order of the
	 * priority values. It is required to return a value between 0 and 100.
	 *
	 * E.g.: 70
	 */
	public function getPriority() {
		return 40;
	}

}
